==> os_basecode-0.0.6.tar.gz: lib/utilities/base_client.dart <==
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:dio/io.dart';
import 'package:flutter/foundation.dart';

class Client {
  String baseURL;
  Map<String, dynamic>? headers;
  bool showLogging;
  Client({required this.baseURL, this.headers, this.showLogging = true});

  Dio init() {
    var dio = Dio();
    if (!kIsWeb) {
      (dio.httpClientAdapter as IOHttpClientAdapter).onHttpClientCreate = (HttpClient client) {
        client.badCertificateCallback = (X509Certificate cert, String host, int port) => true;
        return client;
      };
    }
    dio.options.baseUrl = baseURL;
    dio.options.connectTimeout = const Duration(seconds: 120);
    dio.options.receiveTimeout = const Duration(seconds: 120);
    dio.options.headers = headers;
    dio.interceptors.add(ApiInterceptors(showLogging: showLogging));
    return dio;
  }
}

class ApiInterceptors extends Interceptor {
  bool showLogging;

  ApiInterceptors({this.showLogging = true});
  @override
  void onRequest(RequestOptions options, RequestInterceptorHandler handler) {
    if (showLogging) {
      if (kDebugMode) {
        print('REQUEST[${options.method}] => PATH: ${options.path}');
        print('DATA BODY: [${options.data}]');
      }
    }
    return super.onRequest(options, handler);
  }

  @override
  void onResponse(Response response, ResponseInterceptorHandler handler) {
    if (showLogging) {
      if (kDebugMode) {
        print('RESPONSE[${response.statusCode}] => PATH: ${response.requestOptions.path}');
      }
    }
    return super.onResponse(response, handler);
  }

  @override
  void onError(DioError err, ErrorInterceptorHandler handler) async {
    if (showLogging) {
      if (kDebugMode) {
        print('ERROR[${err.response?.statusCode}] => PATH: ${err.requestOptions.path}');
        print('ERROR MESSAGE : ${err.message}');
      }
    }

    return super.onError(err, handler);
  }
}

==> os_basecode-0.0.7.tar.gz: lib/utilities/base_client.dart <==
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';

class Client {
  String baseURL;
  Map<String, dynamic>? headers;
  bool showLogging;
  Client({required this.baseURL, this.headers, this.showLogging = true});

  Dio init() {
    var dio = Dio();
    dio.options.baseUrl = baseURL;
    dio.options.connectTimeout = const Duration(seconds: 120);
    dio.options.receiveTimeout = const Duration(seconds: 120);
    dio.options.headers = headers;
    dio.interceptors.add(ApiInterceptors(showLogging: showLogging));
    return dio;
  }
}

class ApiInterceptors extends Interceptor {
  bool showLogging;

  ApiInterceptors({this.showLogging = true});
  @override
  void onRequest(RequestOptions options, RequestInterceptorHandler handler) {
    if (showLogging) {
      if (kDebugMode) {
        print('REQUEST[${options.method}] => PATH: ${options.path}');
        print('DATA BODY: [${options.data}]');
      }
    }
    return super.onRequest(options, handler);
  }

  @override
  void onResponse(Response response, ResponseInterceptorHandler handler) {
    if (showLogging) {
      if (kDebugMode) {
        print('RESPONSE[${response.statusCode}] => PATH: ${response.requestOptions.path}');
      }
    }
    return super.onResponse(response, handler);
  }

  @override
  void onError(DioException err, ErrorInterceptorHandler handler) async {
    if (showLogging) {
      if (kDebugMode) {
        print('ERROR[${err.response?.statusCode}] => PATH: ${err.requestOptions.path}');
        print('ERROR MESSAGE : ${err.message}');
      }
    }

    return super.onError(err, handler);
  }
}
